import logging
from logging.config import dictConfig
import os


def configure_logger(log_level=logging.DEBUG, log_level_console=logging.DEBUG, log_level_file=logging.DEBUG, log_file_name="log.txt"):
    dictConfig({
        "version": 1,
        "disable_existing_loggers": False,
        "formatters": {
            "standard": {
                "format": "%(asctime)s | %(name)-30s | %(levelname)-5s | %(funcName)-10s | %(lineno)-5d | %(message)s"
            },
        },
        "handlers": {
            "console": {
                "level": log_level_console,
                "formatter": "standard",
                "class": "logging.StreamHandler",
            },
            "file": {
                "class": "logging.handlers.RotatingFileHandler",
                "formatter": "standard",
                "level": log_level_file,
                "backupCount": 5,
                "maxBytes": 1024 * 1024 * 10,
                "filename": os.path.join(os.path.abspath(os.curdir), log_file_name)
            }
        },
        "loggers": {
            "": {
                "handlers": ["console", "file"],
                "level": log_level,
                "propagate": True
            }
        }
    })